@@ -68,11 +68,11 @@ inline size_t SpecHash(char spectrum)
 // an enum to specify what kind of labels should be attached to stars:
 //  full name, name only for stars with Bayer designations, numerical index,
 //  or none.
-enum label_t { NO_LABEL, NUMBER_LABEL, STRING_LABEL, LANDMARK_LABEL };
+enum star_label_t { NO_LABEL, NUMBER_LABEL, STRING_LABEL, LANDMARK_LABEL };
 
 // an enum to specify whether the diameter of star icons should depend upon
 //  MK class or upon magnitude
-enum diameter_t { MK_DIAMETERS, MAGNITUDE_DIAMETERS };
+enum star_diameter_t { MK_DIAMETERS, MAGNITUDE_DIAMETERS };
 
 #define CELESTIAL 1
 #define GALACTIC  0
@@ -102,8 +102,8 @@ struct Rules {
 
   // some other display toggles: used in the displays
   bool         CelestialCoords;
-  diameter_t   StarDiameters;
-  label_t      StarLabels;
+  star_diameter_t StarDiameters;
+  star_label_t StarLabels;
   bool         StarBars;
   bool         ChartGrid;
   bool         ChartLegend;
@@ -113,7 +113,7 @@ struct Rules {
             const SolidAngle &orientation, double rad,
             float dimmag, float brightmag, bool hide_comps,
 	    bool autoset, const bool classes[10],
-            bool coords, diameter_t diam, label_t label,
+            bool coords, star_diameter_t diam, star_label_t label,
             bool bars, bool grid, bool legend)
   {
     ChartFileNames   = files;
@@ -136,7 +136,7 @@ struct Rules {
   Rules(const StringList &files, const Vector3 &posn,
 	const SolidAngle &orientation, double rad, float dimmag,
 	float brightmag, bool hide_comps, bool autoset, const bool classes[10],
-        bool coords, diameter_t diam, label_t label,
+        bool coords, star_diameter_t diam, star_label_t label,
         bool bars, bool grid, bool legend)
   { Copy(files, posn, orientation, rad, dimmag, brightmag, hide_comps, autoset,
 	 classes, coords, diam, label, bars, grid, legend); 
