@@ -61,12 +61,24 @@ void my_gtk_position_dialog( GtkWidget **entrybox, GtkWidget *insertionbox,
   labeltext[7] = "\"";
 
   if (celestial_coords) {
-    labeltext[1] = "h"; labeltext[2] = "m"; labeltext[3] = "s";
-    labeltext[0] = "Right Ascension:"; labeltext[4] = "Declination:";
+    labeltext[1] =
+      /* TRANSLATORS: This is the abbreviation for
+         "hours of right ascension". */
+      _("h");
+    labeltext[2] =
+      /* TRANSLATORS: This is the abbreviation for
+         "minutes of right ascension". */
+      _("m");
+    labeltext[3] =
+      /* TRANSLATORS: This is the abbreviation for
+         "seconds of right ascension". */
+      _("s");
+    labeltext[0] = _("Right Ascension:"); labeltext[4] = _("Declination:");
   }
   else {
     labeltext[1] = DEGREE_UTF8; labeltext[2] = "'"; labeltext[3] = "\"";
-    labeltext[0] = "Galactic Longitude:"; labeltext[4] = "Galactic Latitude:";
+    labeltext[0] = _("Galactic Longitude:");
+    labeltext[4] = _("Galactic Latitude:");
   }
 
   StringList rastrings=starstrings::ra_to_strs(posn.getPhi(),celestial_coords);
@@ -110,6 +122,9 @@ void my_gtk_position_dialog( GtkWidget **entrybox, GtkWidget *insertionbox,
 
 /* Handler for the Chart->Define Chart menu item */
 
+/* The top-level Chart Define window pointer */
+GtkWidget * definedialog;
+
 /* Callback functions */
 
 /* chart_define_callback(): Set the chart parameters to what was specified
@@ -212,7 +227,9 @@ void chart_define_search(GtkWidget *widget, gpointer chart_define_data)
   // if we don't find anything, leave a message in the star name entry
   //  box and return
   if (! searchresults.size()) {
-    gtk_entry_set_text (GTK_ENTRY (data[8]), "Sorry, not found");
+    my_gtk_error (GTK_WINDOW (definedialog),
+	starstrings::ssprintf(_("Sorry, star \"%s\" not found."),
+	  starname.c_str()).c_str());
     return;
   }
 
@@ -231,7 +248,7 @@ void chart_define_search(GtkWidget *widget, gpointer chart_define_data)
   StringList ra(infolist[2], SUBFIELD_DELIMITER);
   StringList dec(infolist[3], SUBFIELD_DELIMITER);
 
-  if (ra[0] == string("N/A"))
+  if (ra[0] == string(_("N/A")))
     ra = dec = StringList("0,0,0", ',');
 
   for (unsigned int i = 0; i < 3; i++) {
@@ -247,7 +264,7 @@ void chart_define_search(GtkWidget *widget, gpointer chart_define_data)
  *  complicated of the dialog boxes.  Sorry about that. */
 void chart_define()
 {
-  GtkWidget *definedialog, *main_vbox, *query;
+  GtkWidget *main_vbox, *query;
   GtkWidget *lookup_frame, *lookup_hbox, *lookup_entry, *search;
   GtkWidget *coord_frame, *coord_vbox;
   GtkWidget *coord_entry[6], *distance_hbox, *distance_label, *distance_entry;
@@ -259,7 +276,7 @@ void chart_define()
   // The window
   definedialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_policy (GTK_WINDOW (definedialog), false, false, true);
-  gtk_window_set_title (GTK_WINDOW (definedialog), "StarPlot: Define Chart");
+  gtk_window_set_title (GTK_WINDOW (definedialog), _("StarPlot: Define Chart"));
   gtk_window_set_modal (GTK_WINDOW (definedialog), true);
   g_signal_connect (G_OBJECT (definedialog), "destroy",
 		      G_CALLBACK (gtk_widget_destroy), NULL);
@@ -271,14 +288,16 @@ void chart_define()
   gtk_widget_show (main_vbox);
 
   // Query text
-  query = gtk_label_new (" Where should the chart origin be located?");
+  query = gtk_label_new (
+      _("Where should the chart origin be located?"));
   gtk_box_pack_start (GTK_BOX (main_vbox), query, false, false, 0);
   gtk_misc_set_alignment (GTK_MISC (query), 0.0F, 0.0F);
   gtk_widget_show (query);
 
   // First element: a frame containing an hbox containing the star search
   //  entry box
-  lookup_frame = gtk_frame_new ("Enter a star name and press \"Search\"");
+  lookup_frame = gtk_frame_new (
+      _("Enter a star name and press \"Search\""));
   gtk_box_pack_start (GTK_BOX (main_vbox), lookup_frame, false, false, 0);
   gtk_widget_show (lookup_frame);
 
@@ -291,7 +310,7 @@ void chart_define()
   gtk_box_pack_start (GTK_BOX (lookup_hbox), lookup_entry, true, true, 5);
   gtk_widget_show (lookup_entry);
 
-  search = gtk_button_new_with_mnemonic ("_Search");
+  search = gtk_button_new_with_mnemonic (_("_Search"));
   gtk_box_pack_start (GTK_BOX (lookup_hbox), search, false, false, 5);
   gtk_widget_set_usize (search, defaults::program_button_width,
 			defaults::program_button_height);
@@ -299,7 +318,8 @@ void chart_define()
 
   // Second element: a frame containing a vbox containing the coordinate
   //  entry boxes
-  coord_frame = gtk_frame_new ("Or, enter coordinates manually");
+  coord_frame = gtk_frame_new (
+      _("Or, enter coordinates manually"));
   gtk_box_pack_start (GTK_BOX (main_vbox), coord_frame, false, false, 0);
   gtk_widget_show (coord_frame);
 
@@ -316,7 +336,9 @@ void chart_define()
   gtk_box_pack_start (GTK_BOX (coord_vbox), distance_hbox, false, false, 5);
   gtk_widget_show (distance_hbox);
 
-  distance_label = gtk_label_new ("Distance of chart origin from Sun (LY):");
+  distance_label = gtk_label_new (
+      /* TRANSLATORS: "LY" is the abbreviation for "light-years". */
+      _("Distance of chart origin from Sun (LY):"));
   gtk_box_pack_start (GTK_BOX (distance_hbox), distance_label, false, false, 5);
   gtk_widget_show (distance_label);
 
@@ -333,7 +355,9 @@ void chart_define()
   gtk_box_pack_start (GTK_BOX (main_vbox), chartrad_hbox, false, false, 10);
   gtk_widget_show (chartrad_hbox);
 
-  chartrad_label = gtk_label_new ("Radius of chart (LY):");
+  chartrad_label = gtk_label_new (
+      /* TRANSLATORS: "LY" is the abbreviation for "light-years". */
+      _("Radius of chart (LY):"));
   gtk_box_pack_start (GTK_BOX(chartrad_hbox), chartrad_label, false, false, 5);
   gtk_misc_set_alignment (GTK_MISC (chartrad_label), 0.0F, 0.0F);
   gtk_widget_show (chartrad_label);
@@ -422,7 +446,7 @@ void chart_orient()
   // The window
   orientdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_policy (GTK_WINDOW (orientdialog), false, false, true);
-  gtk_window_set_title (GTK_WINDOW (orientdialog), "StarPlot: Orientation");
+  gtk_window_set_title (GTK_WINDOW (orientdialog), _("StarPlot: Orientation"));
   gtk_window_set_modal (GTK_WINDOW (orientdialog), true);
   g_signal_connect (G_OBJECT (orientdialog), "destroy",
 		      G_CALLBACK (gtk_widget_destroy), NULL);
@@ -434,7 +458,7 @@ void chart_orient()
   gtk_widget_show (vbox);
 
   explanation = 
-    gtk_label_new ("Set the orientation of the front of the chart:");
+    gtk_label_new (_("Set the orientation of the front of the chart:"));
   gtk_misc_set_alignment (GTK_MISC (explanation), 0.0F, 0.0F);
   gtk_box_pack_start (GTK_BOX (vbox), explanation, false, false, 0);
   gtk_widget_show (explanation);
@@ -482,6 +506,8 @@ void chart_filter_callback(GtkWidget *widget, gpointer chart_filter_data)
     starmath::atof(gtk_entry_get_text (GTK_ENTRY (data[10])));
   globals::chart_rules.ChartAutosetDimmestMagnitude = 
     GTK_TOGGLE_BUTTON (data[12])->active;
+  globals::chart_rules.ChartHideCompanions =
+    GTK_TOGGLE_BUTTON (data[13])->active;
 
   /* If the user has just turned on the magnitude autoset feature, we should
    *  autoset the dim magnitude limit, UNLESS the user has also just manually
@@ -503,6 +529,7 @@ void chart_filter_defaults(GtkWidget *widget, gpointer data)
     RESET_GLOBAL(chart_rules.StarClasses[i]);
   RESET_GLOBAL(chart_rules.ChartBrightestMagnitude);
   RESET_GLOBAL(chart_rules.ChartDimmestMagnitude);
+  RESET_GLOBAL(chart_rules.ChartHideCompanions);
   RESET_GLOBAL(chart_rules.ChartAutosetDimmestMagnitude);
 
   if (globals::chart_rules.ChartAutosetDimmestMagnitude)
@@ -521,14 +548,15 @@ void chart_filter()
   GtkWidget *filterdialog, *mainbox, *classframe, *magframe;
   GtkWidget *classtable, *classboxes[10], *clabel;
   GtkWidget *magtable, *magentrybox[2], *maglabel[2], *magautoset;
+  GtkWidget *hidecomps;
   GtkWidget *OK, *defaults, *cancel;
-  static GtkWidget *chart_filter_data[13];
+  static GtkWidget *chart_filter_data[14];
   string maglimits[2];
 
   // The window
   filterdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_policy (GTK_WINDOW (filterdialog), false, false, true);
-  gtk_window_set_title (GTK_WINDOW (filterdialog), "StarPlot: Star Filter");
+  gtk_window_set_title (GTK_WINDOW (filterdialog), _("StarPlot: Star Filter"));
   gtk_window_set_modal (GTK_WINDOW (filterdialog), true);
   g_signal_connect (G_OBJECT (filterdialog), "destroy",
 		      G_CALLBACK (gtk_widget_destroy), NULL);
@@ -540,8 +568,9 @@ void chart_filter()
   gtk_widget_show (mainbox);
 
   // Frames in the window
-  classframe = gtk_frame_new ("By Spectral Class");
-  magframe = gtk_frame_new ("By Magnitude");
+  classframe = gtk_frame_new (
+      _("By Spectral Class"));
+  magframe = gtk_frame_new (_("By Magnitude"));
   gtk_box_pack_start (GTK_BOX (mainbox), classframe, true, false, 0);
   gtk_box_pack_start (GTK_BOX (mainbox), magframe, true, false, 0);
   gtk_widget_show (classframe);
@@ -552,7 +581,7 @@ void chart_filter()
   gtk_container_add (GTK_CONTAINER (classframe), classtable);
   gtk_widget_show (classtable);
 
-  clabel = gtk_label_new ("Indicate which stellar classes to include:");
+  clabel = gtk_label_new (_("Indicate which stellar classes to include:"));
   gtk_widget_show (clabel);
   gtk_misc_set_alignment (GTK_MISC (clabel), 0.0F, 0.0F);
   gtk_table_attach (GTK_TABLE (classtable), clabel, 0, 4, 0, 1,
@@ -560,18 +589,20 @@ void chart_filter()
 		    (GtkAttachOptions)(GTK_FILL | GTK_EXPAND), 5, 5);
 
   classboxes[0] = 
-    gtk_check_button_new_with_mnemonic ("Class _O / Wolf-Rayet");
-  classboxes[1] = gtk_check_button_new_with_mnemonic ("Class _B");
-  classboxes[2] = gtk_check_button_new_with_mnemonic ("Class _A");
-  classboxes[3] = gtk_check_button_new_with_mnemonic ("Class _F");
-  classboxes[4] = gtk_check_button_new_with_mnemonic ("Class _G");
-  classboxes[5] = gtk_check_button_new_with_mnemonic ("Class _K");
-  classboxes[6] = gtk_check_button_new_with_mnemonic ("Class _M");
-  classboxes[7] = gtk_check_button_new_with_mnemonic ("_Dwarf stars");
+    gtk_check_button_new_with_mnemonic (
+	/* TRANSLATORS: "Wolf-Rayet" is a proper name for a type of star. */
+	_("Class _O / Wolf-Rayet"));
+  classboxes[1] = gtk_check_button_new_with_mnemonic (_("Class _B"));
+  classboxes[2] = gtk_check_button_new_with_mnemonic (_("Class _A"));
+  classboxes[3] = gtk_check_button_new_with_mnemonic (_("Class _F"));
+  classboxes[4] = gtk_check_button_new_with_mnemonic (_("Class _G"));
+  classboxes[5] = gtk_check_button_new_with_mnemonic (_("Class _K"));
+  classboxes[6] = gtk_check_button_new_with_mnemonic (_("Class _M"));
+  classboxes[7] = gtk_check_button_new_with_mnemonic (_("_Dwarf stars"));
   classboxes[9] =
-    gtk_check_button_new_with_mnemonic ("Show _Non-Stellar Objects");
+    gtk_check_button_new_with_mnemonic (_("Show _Non-Stellar Objects"));
   classboxes[8] = 
-    gtk_check_button_new_with_mnemonic ("Show _Unclassified Objects");
+    gtk_check_button_new_with_mnemonic (_("Show _Unclassified Objects"));
 
   for (int i = 0; i < 10; i++) {
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (classboxes[i]),
@@ -592,8 +623,8 @@ void chart_filter()
   // Create the magnitude text boxes
   maglimits[0]=starstrings::ftoa(globals::chart_rules.ChartBrightestMagnitude);
   maglimits[1]=starstrings::ftoa(globals::chart_rules.ChartDimmestMagnitude);
-  maglabel[0] = gtk_label_new ("Smallest (brightest) allowed magnitude: ");
-  maglabel[1] = gtk_label_new ("Largest (dimmest) allowed magnitude: ");
+  maglabel[0] = gtk_label_new (_("Smallest (brightest) allowed magnitude: "));
+  maglabel[1] = gtk_label_new (_("Largest (dimmest) allowed magnitude: "));
 
   magtable = gtk_table_new (3, 2, false);
   gtk_container_add (GTK_CONTAINER (magframe), magtable);
@@ -618,7 +649,7 @@ void chart_filter()
   }
 
   magautoset = gtk_check_button_new_with_mnemonic
-    ("Auto_set dim magnitude limit based on chart radius");
+    (_("Automatically set dim magnitude limit\nbased on _chart radius"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (magautoset),
     globals::chart_rules.ChartAutosetDimmestMagnitude);
   gtk_table_attach (GTK_TABLE (magtable), magautoset, 0, 2, 2, 3,
@@ -626,6 +657,14 @@ void chart_filter()
   gtk_widget_show (magautoset);
   chart_filter_data[12] = magautoset;
 
+  hidecomps = gtk_check_button_new_with_mnemonic
+    (_("_Hide nearby companion stars"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (hidecomps),
+    globals::chart_rules.ChartHideCompanions);
+  gtk_box_pack_start (GTK_BOX (mainbox), hidecomps, true, false, 0);
+  gtk_widget_show (hidecomps);
+  chart_filter_data[13] = hidecomps;
+
   // set up the buttons
   my_gtk_button_bar (&OK, &defaults, &cancel, mainbox);
   g_signal_connect (G_OBJECT (OK), "clicked", 
