@@ -77,13 +77,12 @@ void my_gtk_star_popup(Star &s)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (popup)->vbox), topbox,
 		      true, true, 0);
 
+#if HAVE_GTK_EXPANDER_NEW
   // name
   expander = gtk_expander_new ((string("<big><b>") + Name.c_str()
       + "</b></big>").c_str());
   gtk_expander_set_use_markup (GTK_EXPANDER (expander), true);
   gtk_expander_set_expanded (GTK_EXPANDER (expander), false);
-  gtk_widget_show (expander);
-  gtk_box_pack_start (GTK_BOX (topbox), expander, false, false, 0);
 
   // alternate names
   namebox = gtk_vbox_new (true, 0);
@@ -99,7 +98,12 @@ void my_gtk_star_popup(Star &s)
     gtk_widget_show (altname);
     gtk_box_pack_start (GTK_BOX (namebox), altname, true, true, 0);
   }
-
+#else // no GtkExpander widget, just show best-known name
+  expander = gtk_label_new (Name.c_str());
+#endif
+  gtk_widget_show (expander);
+  gtk_box_pack_start (GTK_BOX (topbox), expander, false, false, 0);
+  
   separator = gtk_hseparator_new ();
   gtk_widget_show (separator);
   gtk_box_pack_start (GTK_BOX (topbox), separator, false, false, 5);
