@@ -74,8 +74,8 @@ namespace defaults {
   // If you edit the following two lines, you also must reorder the menu items
   //  in menuops.cc so that this default is the first of the starlabel menu
   //  items.  Otherwise the initial toggle setting will not match this default.
-  const diameter_t    display_starsize	= MAGNITUDE_DIAMETERS;
-  const label_t	      display_label_type= LANDMARK_LABEL;
+  const star_diameter_t display_starsize= MAGNITUDE_DIAMETERS;
+  const star_label_t  display_label_type= LANDMARK_LABEL;
 
   const bool	      display_bars	= true;
   const bool	      display_grid	= true;
@@ -162,16 +162,16 @@ extern void my_gtk_error (GtkWindow *parent_win, const char * error_msg);
 extern void hr_redraw_display(GtkWidget *hr_display);
 extern void set_widget_font(GtkWidget *pixmap, std::string font_description);
 extern void update_info(GtkTreeView *info_treeview);
-extern void redraw_all (changetype_t);
+extern void redraw_all (star_changetype_t);
 
 // Functions to set menu toggle/radio buttons
 
 template<class T> extern void 
-set_item(T *, T, GtkWidget *, bool, changetype_t = DECORATIONS_CHANGE);
+set_item(T *, T, GtkWidget *, bool, star_changetype_t = DECORATIONS_CHANGE);
 extern void flip_toggle_item(bool *, int, bool);
 extern void set_toggle_item(bool *, bool, int, bool);
-extern void set_label_item(label_t, bool);
-extern void set_diameter_item(diameter_t, bool);
+extern void set_label_item(star_label_t, bool);
+extern void set_diameter_item(star_diameter_t, bool);
 extern void set_coord_item(bool, bool);
 
 #endif // #include _STARPLOT_H
